[Qa-jenkins-scm] [jenkins.debian.net] 01/01: reproducible Arch Linux: count total number of unknown+untested packages

Holger Levsen holger at layer-acht.org
Wed Nov 29 20:44:11 UTC 2017


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit 69f5e83a12f3ed8807785e24eff3818bfe1a1714
Author: Holger Levsen <holger at layer-acht.org>
Date:   Wed Nov 29 20:44:00 2017 +0000

    reproducible Arch Linux: count total number of unknown+untested packages
    
    Signed-off-by: Holger Levsen <holger at layer-acht.org>
---
 bin/reproducible_html_archlinux.sh | 16 ++++++++++++----
 1 file changed, 12 insertions(+), 4 deletions(-)

diff --git a/bin/reproducible_html_archlinux.sh b/bin/reproducible_html_archlinux.sh
index 28a92ef..24fd413 100755
--- a/bin/reproducible_html_archlinux.sh
+++ b/bin/reproducible_html_archlinux.sh
@@ -215,10 +215,14 @@ for REPOSITORY in $ARCHLINUX_REPOS ; do
 	done
 	echo "     </tr>" >> $HTML_REPOSTATS
 	#
 	# write csv file for $REPO
 	#
-	if ! grep -q $DATE $ARCHBASE/$REPO.csv ; then
-		echo $DATE,$NR_GOOD,$NR_FTBR,$NR_FTBFS,$NR_DEPWAIT,$NR_404,$NR_UNKNOWN >> $ARCHBASE/$REPO.csv
+	if [ ! -f $ARCHBASE/$REPOSITORY.csv ] ; then
+		echo "# date, reproducible, unreproducible, ftbfs, depwait, 404, untested" > $ARCHBASE/$REPOSITORY.csv
+	fi
+	if ! grep -q $DATE $ARCHBASE/$REPOSITORY.csv ; then
+		let REAL_UNKNOWN=$TOTAL-$NR_GOOD-$NR_FTBR-$NR_FTBFS-$NR_DEPWAIT-$NR_404
+		echo $DATE,$NR_GOOD,$NR_FTBR,$NR_FTBFS,$NR_DEPWAIT,$NR_404,$REAL_UNKNOWN >> $ARCHBASE/$REPOSITORY.csv
 	fi
 	#
 	# prepare ARCHLINUX totals
@@ -256,8 +260,12 @@ echo "     </tr>" >> $HTML_REPOSTATS
 #
 # write csv file for totals
 #
+if [ ! -f $ARCHBASE/archlinux.csv ] ; then
+	echo "# date, reproducible, unreproducible, ftbfs, depwait, 404, untested" > $ARCHBASE/archlinux.csv
+fi
 if ! grep -q $DATE $ARCHBASE/archlinux.csv ; then
-	echo $DATE,$ARCHLINUX_NR_GOOD,$ARCHLINUX_NR_FTBR,$ARCHLINUX_NR_FTBFS,$ARCHLINUX_NR_DEPWAIT,$ARCHLINUX_NR_404,$ARCHLINUX_NR_UNKNOWN >> $ARCHBASE/archlinux.csv
+	let ARCHLINUX_REAL_UNKNOWN=$ARCHLINUX_TOTAL-$ARCHLINUX_NR_GOOD-$ARCHLINUX_NR_FTBR-$ARCHLINUX_NR_FTBFS-$ARCHLINUX_NR_DEPWAIT-$ARCHLINUX_NR_404
+	echo $DATE,$ARCHLINUX_NR_GOOD,$ARCHLINUX_NR_FTBR,$ARCHLINUX_NR_FTBFS,$ARCHLINUX_NR_DEPWAIT,$ARCHLINUX_NR_404,$ARCHLINUX_REAL_UNKNOWN >> $ARCHBASE/archlinux.csv
 fi
 
 #
@@ -215,10 +215,14 @@ for REPOSITORY in $ARCHLINUX_REPOS ; do
 	echo "     </tr>" >> $HTML_REPOSTATS
 	#
-	# write csv file for $REPO
+	# write csv file for $REPOSITORY
 	#

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list